@@ -11,6 +11,8 @@ use crate::spec::chart::{ChartVisitor, MutChartVisitor};
 use crate::spec::data::DataSpec;
 use crate::spec::scale::ScaleSpec;
 use crate::spec::signal::SignalSpec;
+use crate::spec::title::TitleSpec;
+use crate::spec::values::StringOrStringList;
 use serde::{Deserialize, Serialize};
 use serde_json::{Number, Value};
 use std::collections::HashMap;
@@ -26,6 +28,9 @@ pub struct MarkSpec {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub from: Option<MarkFromSpec>,
 
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub sort: Option<MarkSort>,
+
     #[serde(skip_serializing_if = "Option::is_none")]
     pub encode: Option<MarkEncodeSpec>,
 
@@ -41,6 +46,12 @@ pub struct MarkSpec {
     #[serde(default, skip_serializing_if = "Vec::is_empty")]
     pub scales: Vec<ScaleSpec>,
 
+    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    pub transform: Vec<Value>,
+
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub title: Option<TitleSpec>,
+
     #[serde(flatten)]
     pub extra: HashMap<String, Value>,
 }
@@ -212,5 +223,24 @@ pub struct MarkFacetSpec {
 #[serde(untagged)]
 pub enum MarkEncodingField {
     Field(String),
-    Object(Value),
+    Object(MarkEncodingFieldObject),
+}
+
+#[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
+pub struct MarkEncodingFieldObject {
+    pub signal: Option<String>,
+    pub datum: Option<String>,
+    pub group: Option<String>,
+    pub parent: Option<String>,
+
+    #[serde(flatten)]
+    pub extra: HashMap<String, Value>,
+}
+
+#[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
+pub struct MarkSort {
+    pub field: StringOrStringList,
+
+    #[serde(flatten)]
+    pub extra: HashMap<String, Value>,
 }
