@@ -44,7 +44,7 @@ async fn eval_spec_sequence_from_files(spec_name: &str) {
 
 async fn eval_spec_get_variable(full_spec: ChartSpec, var: &ScopedVariable) -> QueryResult {
     let local_tz = "America/New_York";
-    let spec_plan = SpecPlan::try_new(&full_spec).unwrap();
+    let spec_plan = SpecPlan::try_new(&full_spec, &Default::default()).unwrap();
     let task_scope = spec_plan.server_spec.to_task_scope().unwrap();
     let tasks = spec_plan.server_spec.to_tasks(local_tz, None).unwrap();
     let task_graph = TaskGraph::new(tasks, &task_scope).unwrap();
@@ -68,7 +68,7 @@ async fn eval_spec_get_variable(full_spec: ChartSpec, var: &ScopedVariable) -> Q
 
 async fn eval_spec_sequence(full_spec: ChartSpec, full_updates: Vec<ExportUpdateBatch>) {
     let local_tz = "America/New_York";
-    let spec_plan = SpecPlan::try_new(&full_spec).unwrap();
+    let spec_plan = SpecPlan::try_new(&full_spec, &Default::default()).unwrap();
     let task_scope = spec_plan.server_spec.to_task_scope().unwrap();
     let comm_plan = spec_plan.comm_plan.clone();
 
