@@ -265,7 +265,9 @@ mod test_vega_specs {
         // case("vega/parallel-coords", 0.001),
         // case("vega/splom-outer", 0.001),
 
-        case("vega/playfair", 0.001),
+        // // Named mark used as a dataset not supported
+        // case("vega/playfair", 0.001),
+
         case("vega/population", 0.001),
         case("vega/quantile-dot-plot", 0.001),
         case("vega/regression", 0.001),
@@ -1152,6 +1154,7 @@ mod test_pre_transform_inline {
         let request = PreTransformRequest {
             spec: serde_json::to_string(&inline_spec).unwrap(),
             local_tz,
+            output_tz: None,
             opts: Some(opts),
         };
         let response = runtime.pre_transform_spec_request(request).await.unwrap();
@@ -1289,6 +1292,7 @@ async fn check_pre_transform_spec_from_files(spec_name: &str, tolerance: f64) {
     let request = PreTransformRequest {
         spec: serde_json::to_string(&full_spec).unwrap(),
         local_tz,
+        output_tz: None,
         opts: Some(opts),
     };
     let response = runtime.pre_transform_spec_request(request).await.unwrap();
