@@ -26,7 +26,7 @@ async fn test_extract_server_data() {
     let mut task_scope = spec.to_task_scope().unwrap();
     // println!("{:#?}", task_scope);
 
-    let server_spec = extract_server_data(&mut spec, &mut task_scope).unwrap();
+    let server_spec = extract_server_data(&mut spec, &mut task_scope, &Default::default()).unwrap();
     // println!("{}", serde_json::to_string_pretty(&server_spec).unwrap());
 
     let client_defs: HashSet<_> = spec.definition_vars().unwrap().into_iter().collect();
@@ -98,7 +98,8 @@ async fn test_extract_stitch_data() {
     // Get full spec's scope
     let mut task_scope = spec.to_task_scope().unwrap();
 
-    let mut server_spec = extract_server_data(&mut spec, &mut task_scope).unwrap();
+    let mut server_spec =
+        extract_server_data(&mut spec, &mut task_scope, &Default::default()).unwrap();
     let comm_plan = stitch_specs(&task_scope, &mut server_spec, &mut spec).unwrap();
 
     println!("{:#?}", comm_plan);
@@ -116,7 +117,8 @@ async fn try_extract_split_server_data() {
     // Get full spec's scope
     let mut task_scope = spec.to_task_scope().unwrap();
 
-    let mut server_spec = extract_server_data(&mut spec, &mut task_scope).unwrap();
+    let mut server_spec =
+        extract_server_data(&mut spec, &mut task_scope, &Default::default()).unwrap();
     let comm_plan = stitch_specs(&task_scope, &mut server_spec, &mut spec).unwrap();
 
     println!("{:#?}", comm_plan);
